@@ -37,7 +37,7 @@ enum  {
 	GTKAML_ATTRIBUTE_TARGET_TYPE
 };
 static gpointer gtkaml_attribute_parent_class = NULL;
-static void gtkaml_attribute_dispose (GObject * obj);
+static void gtkaml_attribute_finalize (GObject * obj);
 
 
 
@@ -54,6 +54,7 @@ void gtkaml_attribute_set_name (GtkamlAttribute* self, const char* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "name");
 }
 
 
@@ -70,6 +71,7 @@ void gtkaml_attribute_set_target_type (GtkamlAttribute* self, ValaSymbol* value)
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_target_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_target_type == NULL ? NULL : (self->priv->_target_type = (g_object_unref (self->priv->_target_type), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "target-type");
 }
 
 
@@ -112,7 +114,7 @@ static void gtkaml_attribute_class_init (GtkamlAttributeClass * klass) {
 	g_type_class_add_private (klass, sizeof (GtkamlAttributePrivate));
 	G_OBJECT_CLASS (klass)->get_property = gtkaml_attribute_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gtkaml_attribute_set_property;
-	G_OBJECT_CLASS (klass)->dispose = gtkaml_attribute_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gtkaml_attribute_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_ATTRIBUTE_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_ATTRIBUTE_TARGET_TYPE, g_param_spec_object ("target-type", "target-type", "target-type", VALA_TYPE_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
@@ -123,18 +125,18 @@ static void gtkaml_attribute_instance_init (GtkamlAttribute * self) {
 }
 
 
-static void gtkaml_attribute_dispose (GObject * obj) {
+static void gtkaml_attribute_finalize (GObject * obj) {
 	GtkamlAttribute * self;
 	self = GTKAML_ATTRIBUTE (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
 	(self->priv->_target_type == NULL ? NULL : (self->priv->_target_type = (g_object_unref (self->priv->_target_type), NULL)));
-	G_OBJECT_CLASS (gtkaml_attribute_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gtkaml_attribute_parent_class)->finalize (obj);
 }
 
 
 GType gtkaml_attribute_get_type (void) {
 	static GType gtkaml_attribute_type_id = 0;
-	if (G_UNLIKELY (gtkaml_attribute_type_id == 0)) {
+	if (gtkaml_attribute_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlAttributeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_attribute_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlAttribute), 0, (GInstanceInitFunc) gtkaml_attribute_instance_init };
 		gtkaml_attribute_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlAttribute", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
