@@ -61,7 +61,7 @@ enum  {
 	GTKAML_CLASS_DEFINITION_PRECONSTRUCT_CODE
 };
 static gpointer gtkaml_class_definition_parent_class = NULL;
-static void gtkaml_class_definition_dispose (GObject * obj);
+static void gtkaml_class_definition_finalize (GObject * obj);
 
 
 
@@ -132,6 +132,7 @@ void gtkaml_class_definition_set_source_reference (GtkamlClassDefinition* self,
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_source_reference = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (g_object_unref (self->priv->_source_reference), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "source-reference");
 }
 
 
@@ -148,6 +149,7 @@ void gtkaml_class_definition_set_identifier (GtkamlClassDefinition* self, const
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_identifier = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_identifier = (g_free (self->priv->_identifier), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "identifier");
 }
 
 
@@ -188,6 +190,7 @@ void gtkaml_class_definition_set_base_ns (GtkamlClassDefinition* self, const cha
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_base_ns = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_base_ns = (g_free (self->priv->_base_ns), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "base-ns");
 }
 
 
@@ -204,6 +207,7 @@ void gtkaml_class_definition_set_base_type (GtkamlClassDefinition* self, ValaCla
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_base_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_base_type == NULL ? NULL : (self->priv->_base_type = (g_object_unref (self->priv->_base_type), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "base-type");
 }
 
 
@@ -220,6 +224,7 @@ void gtkaml_class_definition_set_attrs (GtkamlClassDefinition* self, GeeList* va
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_attrs = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_attrs == NULL ? NULL : (self->priv->_attrs = (g_object_unref (self->priv->_attrs), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "attrs");
 }
 
 
@@ -232,6 +237,7 @@ GtkamlClassDefinition* gtkaml_class_definition_get_parent_container (GtkamlClass
 void gtkaml_class_definition_set_parent_container (GtkamlClassDefinition* self, GtkamlClassDefinition* value) {
 	g_return_if_fail (GTKAML_IS_CLASS_DEFINITION (self));
 	self->priv->_parent_container = value;
+	g_object_notify (((GObject *) (self)), "parent-container");
 }
 
 
@@ -248,6 +254,7 @@ void gtkaml_class_definition_set_children (GtkamlClassDefinition* self, GeeList*
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_children = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_children == NULL ? NULL : (self->priv->_children = (g_object_unref (self->priv->_children), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "children");
 }
 
 
@@ -260,6 +267,7 @@ DefinitionScope gtkaml_class_definition_get_definition_scope (GtkamlClassDefinit
 void gtkaml_class_definition_set_definition_scope (GtkamlClassDefinition* self, DefinitionScope value) {
 	g_return_if_fail (GTKAML_IS_CLASS_DEFINITION (self));
 	self->priv->_definition_scope = value;
+	g_object_notify (((GObject *) (self)), "definition-scope");
 }
 
 
@@ -276,6 +284,7 @@ void gtkaml_class_definition_set_construct_method (GtkamlClassDefinition* self,
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_construct_method = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_construct_method == NULL ? NULL : (self->priv->_construct_method = (g_object_unref (self->priv->_construct_method), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "construct-method");
 }
 
 
@@ -292,6 +301,7 @@ void gtkaml_class_definition_set_add_method (GtkamlClassDefinition* self, Gtkaml
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_add_method = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_add_method == NULL ? NULL : (self->priv->_add_method = (g_object_unref (self->priv->_add_method), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "add-method");
 }
 
 
@@ -308,6 +318,7 @@ void gtkaml_class_definition_set_construct_code (GtkamlClassDefinition* self, co
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_construct_code = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_construct_code = (g_free (self->priv->_construct_code), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "construct-code");
 }
 
 
@@ -324,6 +335,7 @@ void gtkaml_class_definition_set_preconstruct_code (GtkamlClassDefinition* self,
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_preconstruct_code = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_preconstruct_code = (g_free (self->priv->_preconstruct_code), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "preconstruct-code");
 }
 
 
@@ -429,7 +441,7 @@ static void gtkaml_class_definition_class_init (GtkamlClassDefinitionClass * kla
 	g_type_class_add_private (klass, sizeof (GtkamlClassDefinitionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gtkaml_class_definition_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gtkaml_class_definition_set_property;
-	G_OBJECT_CLASS (klass)->dispose = gtkaml_class_definition_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gtkaml_class_definition_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_CLASS_DEFINITION_SOURCE_REFERENCE, g_param_spec_object ("source-reference", "source-reference", "source-reference", VALA_TYPE_SOURCE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_CLASS_DEFINITION_IDENTIFIER, g_param_spec_string ("identifier", "identifier", "identifier", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_CLASS_DEFINITION_BASE_FULL_NAME, g_param_spec_string ("base-full-name", "base-full-name", "base-full-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
@@ -451,7 +463,7 @@ static void gtkaml_class_definition_instance_init (GtkamlClassDefinition * self)
 }
 
 
-static void gtkaml_class_definition_dispose (GObject * obj) {
+static void gtkaml_class_definition_finalize (GObject * obj) {
 	GtkamlClassDefinition * self;
 	self = GTKAML_CLASS_DEFINITION (obj);
 	(self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (g_object_unref (self->priv->_source_reference), NULL)));
@@ -464,13 +476,13 @@ static void gtkaml_class_definition_dispose (GObject * obj) {
 	(self->priv->_add_method == NULL ? NULL : (self->priv->_add_method = (g_object_unref (self->priv->_add_method), NULL)));
 	self->priv->_construct_code = (g_free (self->priv->_construct_code), NULL);
 	self->priv->_preconstruct_code = (g_free (self->priv->_preconstruct_code), NULL);
-	G_OBJECT_CLASS (gtkaml_class_definition_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gtkaml_class_definition_parent_class)->finalize (obj);
 }
 
 
 GType gtkaml_class_definition_get_type (void) {
 	static GType gtkaml_class_definition_type_id = 0;
-	if (G_UNLIKELY (gtkaml_class_definition_type_id == 0)) {
+	if (gtkaml_class_definition_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlClassDefinitionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_class_definition_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlClassDefinition), 0, (GInstanceInitFunc) gtkaml_class_definition_instance_init };
 		gtkaml_class_definition_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlClassDefinition", &g_define_type_info, 0);
 	}
