@@ -59,15 +59,15 @@ struct _GtkamlCodeGeneratorPrivate {
 
 #define GTKAML_CODE_GENERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTKAML_TYPE_CODE_GENERATOR, GtkamlCodeGeneratorPrivate))
 enum  {
-	GTKAML_CODE_GENERATOR_DUMMY_PROPERTY
+	GTKAML_CODE_GENERATOR_DUMMY_PROPERTY,
+	GTKAML_CODE_GENERATOR_CONTEXT
 };
 static gint gtkaml_code_generator_line_count (GtkamlCodeGenerator* self, const char* s);
-static ValaCodeContext* gtkaml_code_generator_get_context (GtkamlCodeGenerator* self);
 static void gtkaml_code_generator_set_context (GtkamlCodeGenerator* self, ValaCodeContext* value);
 static GtkamlRootClassDefinition* gtkaml_code_generator_get_root_class_definition (GtkamlCodeGenerator* self);
 static void gtkaml_code_generator_set_root_class_definition (GtkamlCodeGenerator* self, GtkamlRootClassDefinition* value);
 static gpointer gtkaml_code_generator_parent_class = NULL;
-static void gtkaml_code_generator_dispose (GObject * obj);
+static void gtkaml_code_generator_finalize (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -1014,7 +1014,7 @@ void gtkaml_code_generator_add_code (GtkamlCodeGenerator* self, const char* valu
 }
 
 
-static ValaCodeContext* gtkaml_code_generator_get_context (GtkamlCodeGenerator* self) {
+ValaCodeContext* gtkaml_code_generator_get_context (GtkamlCodeGenerator* self) {
 	g_return_val_if_fail (GTKAML_IS_CODE_GENERATOR (self), NULL);
 	return self->priv->_context;
 }
@@ -1027,6 +1027,7 @@ static void gtkaml_code_generator_set_context (GtkamlCodeGenerator* self, ValaCo
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_context = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_context == NULL ? NULL : (self->priv->_context = (g_object_unref (self->priv->_context), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "context");
 }
 
 
@@ -1050,6 +1051,9 @@ static void gtkaml_code_generator_get_property (GObject * object, guint property
 	GtkamlCodeGenerator * self;
 	self = GTKAML_CODE_GENERATOR (object);
 	switch (property_id) {
+		case GTKAML_CODE_GENERATOR_CONTEXT:
+		g_value_set_object (value, gtkaml_code_generator_get_context (self));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -1061,6 +1065,9 @@ static void gtkaml_code_generator_set_property (GObject * object, guint property
 	GtkamlCodeGenerator * self;
 	self = GTKAML_CODE_GENERATOR (object);
 	switch (property_id) {
+		case GTKAML_CODE_GENERATOR_CONTEXT:
+		gtkaml_code_generator_set_context (self, g_value_get_object (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -1073,7 +1080,8 @@ static void gtkaml_code_generator_class_init (GtkamlCodeGeneratorClass * klass)
 	g_type_class_add_private (klass, sizeof (GtkamlCodeGeneratorPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gtkaml_code_generator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gtkaml_code_generator_set_property;
-	G_OBJECT_CLASS (klass)->dispose = gtkaml_code_generator_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gtkaml_code_generator_finalize;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_CODE_GENERATOR_CONTEXT, g_param_spec_object ("context", "context", "context", VALA_TYPE_CODE_CONTEXT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -1091,7 +1099,7 @@ static void gtkaml_code_generator_instance_init (GtkamlCodeGenerator * self) {
 }
 
 
-static void gtkaml_code_generator_dispose (GObject * obj) {
+static void gtkaml_code_generator_finalize (GObject * obj) {
 	GtkamlCodeGenerator * self;
 	self = GTKAML_CODE_GENERATOR (obj);
 	self->priv->using_directives = (g_free (self->priv->using_directives), NULL);
@@ -1105,13 +1113,13 @@ static void gtkaml_code_generator_dispose (GObject * obj) {
 	self->priv->class_end = (g_free (self->priv->class_end), NULL);
 	(self->priv->_context == NULL ? NULL : (self->priv->_context = (g_object_unref (self->priv->_context), NULL)));
 	(self->priv->_root_class_definition == NULL ? NULL : (self->priv->_root_class_definition = (g_object_unref (self->priv->_root_class_definition), NULL)));
-	G_OBJECT_CLASS (gtkaml_code_generator_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gtkaml_code_generator_parent_class)->finalize (obj);
 }
 
 
 GType gtkaml_code_generator_get_type (void) {
 	static GType gtkaml_code_generator_type_id = 0;
-	if (G_UNLIKELY (gtkaml_code_generator_type_id == 0)) {
+	if (gtkaml_code_generator_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlCodeGeneratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_code_generator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlCodeGenerator), 0, (GInstanceInitFunc) gtkaml_code_generator_instance_init };
 		gtkaml_code_generator_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlCodeGenerator", &g_define_type_info, 0);
 	}
