@@ -35,7 +35,7 @@ enum  {
 	GTKAML_COMPLEX_ATTRIBUTE_COMPLEX_TYPE
 };
 static gpointer gtkaml_complex_attribute_parent_class = NULL;
-static void gtkaml_complex_attribute_dispose (GObject * obj);
+static void gtkaml_complex_attribute_finalize (GObject * obj);
 
 
 
@@ -63,6 +63,7 @@ void gtkaml_complex_attribute_set_complex_type (GtkamlComplexAttribute* self, Gt
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_complex_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_complex_type == NULL ? NULL : (self->priv->_complex_type = (g_object_unref (self->priv->_complex_type), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "complex-type");
 }
 
 
@@ -99,7 +100,7 @@ static void gtkaml_complex_attribute_class_init (GtkamlComplexAttributeClass * k
 	g_type_class_add_private (klass, sizeof (GtkamlComplexAttributePrivate));
 	G_OBJECT_CLASS (klass)->get_property = gtkaml_complex_attribute_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gtkaml_complex_attribute_set_property;
-	G_OBJECT_CLASS (klass)->dispose = gtkaml_complex_attribute_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gtkaml_complex_attribute_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_COMPLEX_ATTRIBUTE_COMPLEX_TYPE, g_param_spec_object ("complex-type", "complex-type", "complex-type", GTKAML_TYPE_CLASS_DEFINITION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
@@ -109,17 +110,17 @@ static void gtkaml_complex_attribute_instance_init (GtkamlComplexAttribute * sel
 }
 
 
-static void gtkaml_complex_attribute_dispose (GObject * obj) {
+static void gtkaml_complex_attribute_finalize (GObject * obj) {
 	GtkamlComplexAttribute * self;
 	self = GTKAML_COMPLEX_ATTRIBUTE (obj);
 	(self->priv->_complex_type == NULL ? NULL : (self->priv->_complex_type = (g_object_unref (self->priv->_complex_type), NULL)));
-	G_OBJECT_CLASS (gtkaml_complex_attribute_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gtkaml_complex_attribute_parent_class)->finalize (obj);
 }
 
 
 GType gtkaml_complex_attribute_get_type (void) {
 	static GType gtkaml_complex_attribute_type_id = 0;
-	if (G_UNLIKELY (gtkaml_complex_attribute_type_id == 0)) {
+	if (gtkaml_complex_attribute_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlComplexAttributeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_complex_attribute_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlComplexAttribute), 0, (GInstanceInitFunc) gtkaml_complex_attribute_instance_init };
 		gtkaml_complex_attribute_type_id = g_type_register_static (GTKAML_TYPE_ATTRIBUTE, "GtkamlComplexAttribute", &g_define_type_info, 0);
 	}
