@@ -52,7 +52,8 @@ struct _GtkamlImplicitsResolverPrivate {
 #define GTKAML_IMPLICITS_RESOLVER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTKAML_TYPE_IMPLICITS_RESOLVER, GtkamlImplicitsResolverPrivate))
 enum  {
 	GTKAML_IMPLICITS_RESOLVER_DUMMY_PROPERTY,
-	GTKAML_IMPLICITS_RESOLVER_IMPLICITS_STORE
+	GTKAML_IMPLICITS_RESOLVER_IMPLICITS_STORE,
+	GTKAML_IMPLICITS_RESOLVER_CONTEXT
 };
 static void gtkaml_implicits_resolver_determine_add_method (GtkamlImplicitsResolver* self, GtkamlClassDefinition* child_definition);
 static void gtkaml_implicits_resolver_determine_construct_method (GtkamlImplicitsResolver* self, GtkamlClassDefinition* class_definition);
@@ -63,10 +64,9 @@ static ValaMember* gtkaml_implicits_resolver_member_lookup_inherited (GtkamlImpl
 static ValaClass* gtkaml_implicits_resolver_lookup_class (GtkamlImplicitsResolver* self, const char* xmlNamespace, const char* name);
 static GeeList* gtkaml_implicits_resolver_lookup_constructors (GtkamlImplicitsResolver* self, ValaClass* clazz);
 static void gtkaml_implicits_resolver_set_implicits_store (GtkamlImplicitsResolver* self, GtkamlImplicitsStore* value);
-static ValaCodeContext* gtkaml_implicits_resolver_get_context (GtkamlImplicitsResolver* self);
 static void gtkaml_implicits_resolver_set_context (GtkamlImplicitsResolver* self, ValaCodeContext* value);
 static gpointer gtkaml_implicits_resolver_parent_class = NULL;
-static void gtkaml_implicits_resolver_dispose (GObject * obj);
+static void gtkaml_implicits_resolver_finalize (GObject * obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -747,10 +747,11 @@ static void gtkaml_implicits_resolver_set_implicits_store (GtkamlImplicitsResolv
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_implicits_store = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_implicits_store == NULL ? NULL : (self->priv->_implicits_store = (g_object_unref (self->priv->_implicits_store), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "implicits-store");
 }
 
 
-static ValaCodeContext* gtkaml_implicits_resolver_get_context (GtkamlImplicitsResolver* self) {
+ValaCodeContext* gtkaml_implicits_resolver_get_context (GtkamlImplicitsResolver* self) {
 	g_return_val_if_fail (GTKAML_IS_IMPLICITS_RESOLVER (self), NULL);
 	return self->priv->_context;
 }
@@ -763,6 +764,7 @@ static void gtkaml_implicits_resolver_set_context (GtkamlImplicitsResolver* self
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_context = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_context == NULL ? NULL : (self->priv->_context = (g_object_unref (self->priv->_context), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "context");
 }
 
 
@@ -773,6 +775,9 @@ static void gtkaml_implicits_resolver_get_property (GObject * object, guint prop
 		case GTKAML_IMPLICITS_RESOLVER_IMPLICITS_STORE:
 		g_value_set_object (value, gtkaml_implicits_resolver_get_implicits_store (self));
 		break;
+		case GTKAML_IMPLICITS_RESOLVER_CONTEXT:
+		g_value_set_object (value, gtkaml_implicits_resolver_get_context (self));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -787,6 +792,9 @@ static void gtkaml_implicits_resolver_set_property (GObject * object, guint prop
 		case GTKAML_IMPLICITS_RESOLVER_IMPLICITS_STORE:
 		gtkaml_implicits_resolver_set_implicits_store (self, g_value_get_object (value));
 		break;
+		case GTKAML_IMPLICITS_RESOLVER_CONTEXT:
+		gtkaml_implicits_resolver_set_context (self, g_value_get_object (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -799,8 +807,9 @@ static void gtkaml_implicits_resolver_class_init (GtkamlImplicitsResolverClass *
 	g_type_class_add_private (klass, sizeof (GtkamlImplicitsResolverPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gtkaml_implicits_resolver_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gtkaml_implicits_resolver_set_property;
-	G_OBJECT_CLASS (klass)->dispose = gtkaml_implicits_resolver_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gtkaml_implicits_resolver_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_IMPLICITS_RESOLVER_IMPLICITS_STORE, g_param_spec_object ("implicits-store", "implicits-store", "implicits-store", GTKAML_TYPE_IMPLICITS_STORE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_IMPLICITS_RESOLVER_CONTEXT, g_param_spec_object ("context", "context", "context", VALA_TYPE_CODE_CONTEXT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -809,18 +818,18 @@ static void gtkaml_implicits_resolver_instance_init (GtkamlImplicitsResolver * s
 }
 
 
-static void gtkaml_implicits_resolver_dispose (GObject * obj) {
+static void gtkaml_implicits_resolver_finalize (GObject * obj) {
 	GtkamlImplicitsResolver * self;
 	self = GTKAML_IMPLICITS_RESOLVER (obj);
 	(self->priv->_implicits_store == NULL ? NULL : (self->priv->_implicits_store = (g_object_unref (self->priv->_implicits_store), NULL)));
 	(self->priv->_context == NULL ? NULL : (self->priv->_context = (g_object_unref (self->priv->_context), NULL)));
-	G_OBJECT_CLASS (gtkaml_implicits_resolver_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gtkaml_implicits_resolver_parent_class)->finalize (obj);
 }
 
 
 GType gtkaml_implicits_resolver_get_type (void) {
 	static GType gtkaml_implicits_resolver_type_id = 0;
-	if (G_UNLIKELY (gtkaml_implicits_resolver_type_id == 0)) {
+	if (gtkaml_implicits_resolver_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlImplicitsResolverClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_implicits_resolver_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlImplicitsResolver), 0, (GInstanceInitFunc) gtkaml_implicits_resolver_instance_init };
 		gtkaml_implicits_resolver_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlImplicitsResolver", &g_define_type_info, 0);
 	}
