@@ -62,7 +62,7 @@ enum  {
 	GTKAML_IMPLICITS_PARAMETER_DUMMY_PROPERTY
 };
 static gpointer gtkaml_implicits_parameter_parent_class = NULL;
-static void gtkaml_implicits_parameter_dispose (GObject * obj);
+static void gtkaml_implicits_parameter_finalize (GObject * obj);
 enum  {
 	GTKAML_KEY_FILE_WRAPPER_DUMMY_PROPERTY
 };
@@ -71,7 +71,7 @@ static char** gtkaml_key_file_wrapper_get_string_list (GtkamlKeyFileWrapper* sel
 static GtkamlKeyFileWrapper* gtkaml_key_file_wrapper_new (void);
 static GObject * gtkaml_key_file_wrapper_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer gtkaml_key_file_wrapper_parent_class = NULL;
-static void gtkaml_key_file_wrapper_dispose (GObject * obj);
+static void gtkaml_key_file_wrapper_finalize (GObject * obj);
 static GType gtkaml_key_file_wrapper_get_type (void);
 struct _GtkamlImplicitsStorePrivate {
 	GeeList* implicits_dirs;
@@ -84,7 +84,7 @@ enum  {
 };
 static GeeList* gtkaml_implicits_store_get_ns (GtkamlImplicitsStore* self, const char* ns);
 static gpointer gtkaml_implicits_store_parent_class = NULL;
-static void gtkaml_implicits_store_dispose (GObject * obj);
+static void gtkaml_implicits_store_finalize (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
@@ -99,7 +99,7 @@ GtkamlImplicitsParameter* gtkaml_implicits_parameter_new (void) {
 
 static void gtkaml_implicits_parameter_class_init (GtkamlImplicitsParameterClass * klass) {
 	gtkaml_implicits_parameter_parent_class = g_type_class_peek_parent (klass);
-	G_OBJECT_CLASS (klass)->dispose = gtkaml_implicits_parameter_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gtkaml_implicits_parameter_finalize;
 }
 
 
@@ -107,18 +107,18 @@ static void gtkaml_implicits_parameter_instance_init (GtkamlImplicitsParameter *
 }
 
 
-static void gtkaml_implicits_parameter_dispose (GObject * obj) {
+static void gtkaml_implicits_parameter_finalize (GObject * obj) {
 	GtkamlImplicitsParameter * self;
 	self = GTKAML_IMPLICITS_PARAMETER (obj);
 	self->name = (g_free (self->name), NULL);
 	self->default_value = (g_free (self->default_value), NULL);
-	G_OBJECT_CLASS (gtkaml_implicits_parameter_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gtkaml_implicits_parameter_parent_class)->finalize (obj);
 }
 
 
 GType gtkaml_implicits_parameter_get_type (void) {
 	static GType gtkaml_implicits_parameter_type_id = 0;
-	if (G_UNLIKELY (gtkaml_implicits_parameter_type_id == 0)) {
+	if (gtkaml_implicits_parameter_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlImplicitsParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_implicits_parameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlImplicitsParameter), 0, (GInstanceInitFunc) gtkaml_implicits_parameter_instance_init };
 		gtkaml_implicits_parameter_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlImplicitsParameter", &g_define_type_info, 0);
 	}
@@ -142,7 +142,8 @@ static gboolean gtkaml_key_file_wrapper_has_key (GtkamlKeyFileWrapper* self, con
 		e = inner_error;
 		inner_error = NULL;
 		{
-			return FALSE;
+			gboolean _tmp1;
+			return (_tmp1 = FALSE, (e == NULL ? NULL : (e = (g_error_free (e), NULL))), _tmp1);
 		}
 	}
 	__finally4:
@@ -170,8 +171,10 @@ static char** gtkaml_key_file_wrapper_get_string_list (GtkamlKeyFileWrapper* sel
 		inner_error = NULL;
 		{
 			char** _tmp3;
+			char** _tmp4;
 			_tmp3 = NULL;
-			return (_tmp3 = g_new0 (char*, 0 + 1), (*result_length1) = 0, _tmp3);
+			_tmp4 = NULL;
+			return (_tmp4 = (_tmp3 = g_new0 (char*, 0 + 1), (*result_length1) = 0, _tmp3), (e == NULL ? NULL : (e = (g_error_free (e), NULL))), _tmp4);
 		}
 	}
 	__finally5:
@@ -210,7 +213,7 @@ static GObject * gtkaml_key_file_wrapper_constructor (GType type, guint n_constr
 static void gtkaml_key_file_wrapper_class_init (GtkamlKeyFileWrapperClass * klass) {
 	gtkaml_key_file_wrapper_parent_class = g_type_class_peek_parent (klass);
 	G_OBJECT_CLASS (klass)->constructor = gtkaml_key_file_wrapper_constructor;
-	G_OBJECT_CLASS (klass)->dispose = gtkaml_key_file_wrapper_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gtkaml_key_file_wrapper_finalize;
 }
 
 
@@ -218,17 +221,17 @@ static void gtkaml_key_file_wrapper_instance_init (GtkamlKeyFileWrapper * self)
 }
 
 
-static void gtkaml_key_file_wrapper_dispose (GObject * obj) {
+static void gtkaml_key_file_wrapper_finalize (GObject * obj) {
 	GtkamlKeyFileWrapper * self;
 	self = GTKAML_KEY_FILE_WRAPPER (obj);
 	(self->key_file == NULL ? NULL : (self->key_file = (g_key_file_free (self->key_file), NULL)));
-	G_OBJECT_CLASS (gtkaml_key_file_wrapper_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gtkaml_key_file_wrapper_parent_class)->finalize (obj);
 }
 
 
 static GType gtkaml_key_file_wrapper_get_type (void) {
 	static GType gtkaml_key_file_wrapper_type_id = 0;
-	if (G_UNLIKELY (gtkaml_key_file_wrapper_type_id == 0)) {
+	if (gtkaml_key_file_wrapper_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlKeyFileWrapperClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_key_file_wrapper_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlKeyFileWrapper), 0, (GInstanceInitFunc) gtkaml_key_file_wrapper_instance_init };
 		gtkaml_key_file_wrapper_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlKeyFileWrapper", &g_define_type_info, 0);
 	}
@@ -294,6 +297,7 @@ static GeeList* gtkaml_implicits_store_get_ns (GtkamlImplicitsStore* self, const
 								_tmp3 = NULL;
 								vala_report_warning (NULL, (_tmp3 = g_strdup_printf ("Invalid implicits file %s", file_name)));
 								_tmp3 = (g_free (_tmp3), NULL);
+								(e == NULL ? NULL : (e = (g_error_free (e), NULL)));
 							}
 						}
 						__finally6:
@@ -535,7 +539,7 @@ GtkamlImplicitsStore* gtkaml_implicits_store_new (void) {
 static void gtkaml_implicits_store_class_init (GtkamlImplicitsStoreClass * klass) {
 	gtkaml_implicits_store_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GtkamlImplicitsStorePrivate));
-	G_OBJECT_CLASS (klass)->dispose = gtkaml_implicits_store_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gtkaml_implicits_store_finalize;
 }
 
 
@@ -546,18 +550,18 @@ static void gtkaml_implicits_store_instance_init (GtkamlImplicitsStore * self) {
 }
 
 
-static void gtkaml_implicits_store_dispose (GObject * obj) {
+static void gtkaml_implicits_store_finalize (GObject * obj) {
 	GtkamlImplicitsStore * self;
 	self = GTKAML_IMPLICITS_STORE (obj);
 	(self->priv->implicits_dirs == NULL ? NULL : (self->priv->implicits_dirs = (g_object_unref (self->priv->implicits_dirs), NULL)));
 	(self->priv->loaded_ns == NULL ? NULL : (self->priv->loaded_ns = (g_object_unref (self->priv->loaded_ns), NULL)));
-	G_OBJECT_CLASS (gtkaml_implicits_store_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gtkaml_implicits_store_parent_class)->finalize (obj);
 }
 
 
 GType gtkaml_implicits_store_get_type (void) {
 	static GType gtkaml_implicits_store_type_id = 0;
-	if (G_UNLIKELY (gtkaml_implicits_store_type_id == 0)) {
+	if (gtkaml_implicits_store_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlImplicitsStoreClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_implicits_store_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlImplicitsStore), 0, (GInstanceInitFunc) gtkaml_implicits_store_instance_init };
 		gtkaml_implicits_store_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlImplicitsStore", &g_define_type_info, 0);
 	}
