@@ -40,7 +40,7 @@ enum  {
 };
 static GObject * gtkaml_method_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer gtkaml_method_parent_class = NULL;
-static void gtkaml_method_dispose (GObject * obj);
+static void gtkaml_method_finalize (GObject * obj);
 enum  {
 	GTKAML_ADD_METHOD_DUMMY_PROPERTY
 };
@@ -65,6 +65,7 @@ void gtkaml_method_set_name (GtkamlMethod* self, const char* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "name");
 }
 
 
@@ -81,6 +82,7 @@ void gtkaml_method_set_parameter_attributes (GtkamlMethod* self, GeeList* value)
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_parameter_attributes = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_parameter_attributes == NULL ? NULL : (self->priv->_parameter_attributes = (g_object_unref (self->priv->_parameter_attributes), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "parameter-attributes");
 }
 
 
@@ -143,7 +145,7 @@ static void gtkaml_method_class_init (GtkamlMethodClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = gtkaml_method_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gtkaml_method_set_property;
 	G_OBJECT_CLASS (klass)->constructor = gtkaml_method_constructor;
-	G_OBJECT_CLASS (klass)->dispose = gtkaml_method_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gtkaml_method_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_METHOD_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_METHOD_PARAMETER_ATTRIBUTES, g_param_spec_object ("parameter-attributes", "parameter-attributes", "parameter-attributes", GEE_TYPE_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
@@ -154,18 +156,18 @@ static void gtkaml_method_instance_init (GtkamlMethod * self) {
 }
 
 
-static void gtkaml_method_dispose (GObject * obj) {
+static void gtkaml_method_finalize (GObject * obj) {
 	GtkamlMethod * self;
 	self = GTKAML_METHOD (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
 	(self->priv->_parameter_attributes == NULL ? NULL : (self->priv->_parameter_attributes = (g_object_unref (self->priv->_parameter_attributes), NULL)));
-	G_OBJECT_CLASS (gtkaml_method_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gtkaml_method_parent_class)->finalize (obj);
 }
 
 
 GType gtkaml_method_get_type (void) {
 	static GType gtkaml_method_type_id = 0;
-	if (G_UNLIKELY (gtkaml_method_type_id == 0)) {
+	if (gtkaml_method_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlMethod), 0, (GInstanceInitFunc) gtkaml_method_instance_init };
 		gtkaml_method_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlMethod", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
@@ -192,7 +194,7 @@ static void gtkaml_add_method_instance_init (GtkamlAddMethod * self) {
 
 GType gtkaml_add_method_get_type (void) {
 	static GType gtkaml_add_method_type_id = 0;
-	if (G_UNLIKELY (gtkaml_add_method_type_id == 0)) {
+	if (gtkaml_add_method_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlAddMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_add_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlAddMethod), 0, (GInstanceInitFunc) gtkaml_add_method_instance_init };
 		gtkaml_add_method_type_id = g_type_register_static (GTKAML_TYPE_METHOD, "GtkamlAddMethod", &g_define_type_info, 0);
 	}
@@ -219,7 +221,7 @@ static void gtkaml_construct_method_instance_init (GtkamlConstructMethod * self)
 
 GType gtkaml_construct_method_get_type (void) {
 	static GType gtkaml_construct_method_type_id = 0;
-	if (G_UNLIKELY (gtkaml_construct_method_type_id == 0)) {
+	if (gtkaml_construct_method_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlConstructMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_construct_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlConstructMethod), 0, (GInstanceInitFunc) gtkaml_construct_method_instance_init };
 		gtkaml_construct_method_type_id = g_type_register_static (GTKAML_TYPE_METHOD, "GtkamlConstructMethod", &g_define_type_info, 0);
 	}
