@@ -64,7 +64,7 @@ static void gtkaml_method_matcher_set_first_parameter (GtkamlMethodMatcher* self
 static void gtkaml_method_matcher_set_implicits_store (GtkamlMethodMatcher* self, GtkamlImplicitsStore* value);
 static GObject * gtkaml_method_matcher_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer gtkaml_method_matcher_parent_class = NULL;
-static void gtkaml_method_matcher_dispose (GObject * obj);
+static void gtkaml_method_matcher_finalize (GObject * obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -462,6 +462,7 @@ static void gtkaml_method_matcher_set_class_owning_method (GtkamlMethodMatcher*
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_class_owning_method = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_class_owning_method == NULL ? NULL : (self->priv->_class_owning_method = (g_object_unref (self->priv->_class_owning_method), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "class-owning-method");
 }
 
 
@@ -478,6 +479,7 @@ static void gtkaml_method_matcher_set_wording (GtkamlMethodMatcher* self, const
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_wording = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_wording = (g_free (self->priv->_wording), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "wording");
 }
 
 
@@ -494,6 +496,7 @@ static void gtkaml_method_matcher_set_first_parameter (GtkamlMethodMatcher* self
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_first_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_first_parameter == NULL ? NULL : (self->priv->_first_parameter = (g_object_unref (self->priv->_first_parameter), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "first-parameter");
 }
 
 
@@ -510,6 +513,7 @@ static void gtkaml_method_matcher_set_implicits_store (GtkamlMethodMatcher* self
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_implicits_store = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_implicits_store == NULL ? NULL : (self->priv->_implicits_store = (g_object_unref (self->priv->_implicits_store), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "implicits-store");
 }
 
 
@@ -593,7 +597,7 @@ static void gtkaml_method_matcher_class_init (GtkamlMethodMatcherClass * klass)
 	G_OBJECT_CLASS (klass)->get_property = gtkaml_method_matcher_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gtkaml_method_matcher_set_property;
 	G_OBJECT_CLASS (klass)->constructor = gtkaml_method_matcher_constructor;
-	G_OBJECT_CLASS (klass)->dispose = gtkaml_method_matcher_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gtkaml_method_matcher_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_METHOD_MATCHER_CLASS_OWNING_METHOD, g_param_spec_object ("class-owning-method", "class-owning-method", "class-owning-method", GTKAML_TYPE_CLASS_DEFINITION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_METHOD_MATCHER_WORDING, g_param_spec_string ("wording", "wording", "wording", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_METHOD_MATCHER_FIRST_PARAMETER, g_param_spec_object ("first-parameter", "first-parameter", "first-parameter", GTKAML_TYPE_COMPLEX_ATTRIBUTE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
@@ -614,7 +618,7 @@ static void gtkaml_method_matcher_instance_init (GtkamlMethodMatcher * self) {
 }
 
 
-static void gtkaml_method_matcher_dispose (GObject * obj) {
+static void gtkaml_method_matcher_finalize (GObject * obj) {
 	GtkamlMethodMatcher * self;
 	self = GTKAML_METHOD_MATCHER (obj);
 	(self->priv->_class_owning_method == NULL ? NULL : (self->priv->_class_owning_method = (g_object_unref (self->priv->_class_owning_method), NULL)));
@@ -626,13 +630,13 @@ static void gtkaml_method_matcher_dispose (GObject * obj) {
 	(self->priv->min_param_names == NULL ? NULL : (self->priv->min_param_names = (g_object_unref (self->priv->min_param_names), NULL)));
 	(self->priv->max_matches_method == NULL ? NULL : (self->priv->max_matches_method = (g_object_unref (self->priv->max_matches_method), NULL)));
 	(self->priv->max_matches_method_defaulted_parameters == NULL ? NULL : (self->priv->max_matches_method_defaulted_parameters = (g_object_unref (self->priv->max_matches_method_defaulted_parameters), NULL)));
-	G_OBJECT_CLASS (gtkaml_method_matcher_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gtkaml_method_matcher_parent_class)->finalize (obj);
 }
 
 
 GType gtkaml_method_matcher_get_type (void) {
 	static GType gtkaml_method_matcher_type_id = 0;
-	if (G_UNLIKELY (gtkaml_method_matcher_type_id == 0)) {
+	if (gtkaml_method_matcher_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlMethodMatcherClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_method_matcher_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlMethodMatcher), 0, (GInstanceInitFunc) gtkaml_method_matcher_instance_init };
 		gtkaml_method_matcher_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlMethodMatcher", &g_define_type_info, 0);
 	}
