@@ -21,8 +21,6 @@
  */
 
 #include "GtkamlParser.h"
-#include <stdlib.h>
-#include <string.h>
 #include <glib/gstdio.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valareport.h>
@@ -50,7 +48,7 @@ enum  {
 static void gtkaml_parser_real_visit_source_file (ValaCodeVisitor* base, ValaSourceFile* source_file);
 static void gtkaml_parser_real_parse_gtkaml_file (GtkamlParser* self, ValaSourceFile* gtkaml_source_file);
 static gpointer gtkaml_parser_parent_class = NULL;
-static void gtkaml_parser_dispose (GObject * obj);
+static void gtkaml_parser_finalize (GObject * obj);
 
 
 
@@ -207,6 +205,7 @@ static void gtkaml_parser_real_parse_gtkaml_file (GtkamlParser* self, ValaSource
 			inner_error = NULL;
 			{
 				vala_report_error (NULL, e->message);
+				(e == NULL ? NULL : (e = (g_error_free (e), NULL)));
 			}
 		}
 		__finally3:
@@ -228,7 +227,7 @@ void gtkaml_parser_parse_gtkaml_file (GtkamlParser* self, ValaSourceFile* gtkaml
 static void gtkaml_parser_class_init (GtkamlParserClass * klass) {
 	gtkaml_parser_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GtkamlParserPrivate));
-	G_OBJECT_CLASS (klass)->dispose = gtkaml_parser_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gtkaml_parser_finalize;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_source_file = gtkaml_parser_real_visit_source_file;
 	GTKAML_PARSER_CLASS (klass)->parse_gtkaml_file = gtkaml_parser_real_parse_gtkaml_file;
 }
@@ -240,19 +239,19 @@ static void gtkaml_parser_instance_init (GtkamlParser * self) {
 }
 
 
-static void gtkaml_parser_dispose (GObject * obj) {
+static void gtkaml_parser_finalize (GObject * obj) {
 	GtkamlParser * self;
 	self = GTKAML_PARSER (obj);
 	(self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL)));
 	(self->priv->current_source_file == NULL ? NULL : (self->priv->current_source_file = (g_object_unref (self->priv->current_source_file), NULL)));
 	(self->priv->implicits_store == NULL ? NULL : (self->priv->implicits_store = (g_object_unref (self->priv->implicits_store), NULL)));
-	G_OBJECT_CLASS (gtkaml_parser_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gtkaml_parser_parent_class)->finalize (obj);
 }
 
 
 GType gtkaml_parser_get_type (void) {
 	static GType gtkaml_parser_type_id = 0;
-	if (G_UNLIKELY (gtkaml_parser_type_id == 0)) {
+	if (gtkaml_parser_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlParserClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_parser_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlParser), 0, (GInstanceInitFunc) gtkaml_parser_instance_init };
 		gtkaml_parser_type_id = g_type_register_static (VALA_TYPE_PARSER, "GtkamlParser", &g_define_type_info, 0);
 	}
