@@ -47,7 +47,7 @@ enum  {
 	GTKAML_ROOT_CLASS_DEFINITION_IMPLEMENTS
 };
 static gpointer gtkaml_root_class_definition_parent_class = NULL;
-static void gtkaml_root_class_definition_dispose (GObject * obj);
+static void gtkaml_root_class_definition_finalize (GObject * obj);
 
 
 
@@ -101,6 +101,7 @@ void gtkaml_root_class_definition_set_prefixes_namespaces (GtkamlRootClassDefini
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_prefixes_namespaces = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_prefixes_namespaces == NULL ? NULL : (self->priv->_prefixes_namespaces = (g_object_unref (self->priv->_prefixes_namespaces), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "prefixes-namespaces");
 }
 
 
@@ -117,6 +118,7 @@ void gtkaml_root_class_definition_set_target_name (GtkamlRootClassDefinition* se
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_target_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_target_name = (g_free (self->priv->_target_name), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "target-name");
 }
 
 
@@ -133,6 +135,7 @@ void gtkaml_root_class_definition_set_target_namespace (GtkamlRootClassDefinitio
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_target_namespace = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_target_namespace = (g_free (self->priv->_target_namespace), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "target-namespace");
 }
 
 
@@ -149,6 +152,7 @@ void gtkaml_root_class_definition_set_code (GtkamlRootClassDefinition* self, Gee
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_code = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_code == NULL ? NULL : (self->priv->_code = (g_object_unref (self->priv->_code), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "code");
 }
 
 
@@ -161,6 +165,7 @@ gint gtkaml_root_class_definition_get_original_first_code_line (GtkamlRootClassD
 void gtkaml_root_class_definition_set_original_first_code_line (GtkamlRootClassDefinition* self, gint value) {
 	g_return_if_fail (GTKAML_IS_ROOT_CLASS_DEFINITION (self));
 	self->priv->_original_first_code_line = value;
+	g_object_notify (((GObject *) (self)), "original-first-code-line");
 }
 
 
@@ -177,6 +182,7 @@ void gtkaml_root_class_definition_set_implements (GtkamlRootClassDefinition* sel
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_implements = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_implements = (g_free (self->priv->_implements), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "implements");
 }
 
 
@@ -243,7 +249,7 @@ static void gtkaml_root_class_definition_class_init (GtkamlRootClassDefinitionCl
 	g_type_class_add_private (klass, sizeof (GtkamlRootClassDefinitionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gtkaml_root_class_definition_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gtkaml_root_class_definition_set_property;
-	G_OBJECT_CLASS (klass)->dispose = gtkaml_root_class_definition_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gtkaml_root_class_definition_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_ROOT_CLASS_DEFINITION_PREFIXES_NAMESPACES, g_param_spec_object ("prefixes-namespaces", "prefixes-namespaces", "prefixes-namespaces", GEE_TYPE_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_ROOT_CLASS_DEFINITION_TARGET_NAME, g_param_spec_string ("target-name", "target-name", "target-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_ROOT_CLASS_DEFINITION_TARGET_NAMESPACE, g_param_spec_string ("target-namespace", "target-namespace", "target-namespace", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -258,7 +264,7 @@ static void gtkaml_root_class_definition_instance_init (GtkamlRootClassDefinitio
 }
 
 
-static void gtkaml_root_class_definition_dispose (GObject * obj) {
+static void gtkaml_root_class_definition_finalize (GObject * obj) {
 	GtkamlRootClassDefinition * self;
 	self = GTKAML_ROOT_CLASS_DEFINITION (obj);
 	(self->priv->_prefixes_namespaces == NULL ? NULL : (self->priv->_prefixes_namespaces = (g_object_unref (self->priv->_prefixes_namespaces), NULL)));
@@ -266,13 +272,13 @@ static void gtkaml_root_class_definition_dispose (GObject * obj) {
 	self->priv->_target_namespace = (g_free (self->priv->_target_namespace), NULL);
 	(self->priv->_code == NULL ? NULL : (self->priv->_code = (g_object_unref (self->priv->_code), NULL)));
 	self->priv->_implements = (g_free (self->priv->_implements), NULL);
-	G_OBJECT_CLASS (gtkaml_root_class_definition_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gtkaml_root_class_definition_parent_class)->finalize (obj);
 }
 
 
 GType gtkaml_root_class_definition_get_type (void) {
 	static GType gtkaml_root_class_definition_type_id = 0;
-	if (G_UNLIKELY (gtkaml_root_class_definition_type_id == 0)) {
+	if (gtkaml_root_class_definition_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlRootClassDefinitionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_root_class_definition_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlRootClassDefinition), 0, (GInstanceInitFunc) gtkaml_root_class_definition_instance_init };
 		gtkaml_root_class_definition_type_id = g_type_register_static (GTKAML_TYPE_CLASS_DEFINITION, "GtkamlRootClassDefinition", &g_define_type_info, 0);
 	}
