@@ -77,7 +77,7 @@ static GtkamlRootClassDefinition* gtkaml_sax_parser_get_root_class_definition (G
 static void gtkaml_sax_parser_set_root_class_definition (GtkamlSAXParser* self, GtkamlRootClassDefinition* value);
 static GObject * gtkaml_sax_parser_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer gtkaml_sax_parser_parent_class = NULL;
-static void gtkaml_sax_parser_dispose (GObject * obj);
+static void gtkaml_sax_parser_finalize (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -145,6 +145,7 @@ static GtkamlRootClassDefinition* gtkaml_sax_parser_real_parse (GtkamlSAXParser*
 		inner_error = NULL;
 		{
 			vala_report_error (NULL, e->message);
+			(e == NULL ? NULL : (e = (g_error_free (e), NULL)));
 		}
 	}
 	__finally2:
@@ -167,15 +168,15 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 	GeeList* attrs;
 	GtkamlState* state;
 	ValaSourceReference* source_reference;
-	GtkamlStateId _tmp23;
+	GtkamlStateId _tmp24;
 	g_return_if_fail (GTKAML_IS_SAX_PARSER (self));
 	g_return_if_fail (localname != NULL);
 	g_return_if_fail (URI != NULL);
 	attrs = gtkaml_sax_parser_parse_attributes (self, attributes, nb_attributes);
 	state = gtkaml_state_stack_peek (self->priv->_states, 0);
 	source_reference = gtkaml_sax_parser_create_source_reference (self);
-	_tmp23 = gtkaml_state_get_state_id (state);
-	if (_tmp23 == GTKAML_STATE_ID_SAX_PARSER_INITIAL_STATE)
+	_tmp24 = gtkaml_state_get_state_id (state);
+	if (_tmp24 == GTKAML_STATE_ID_SAX_PARSER_INITIAL_STATE)
 	do {
 		{
 			GeeList* nss;
@@ -252,7 +253,7 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 			(clazz == NULL ? NULL : (clazz = (g_object_unref (clazz), NULL)));
 			break;
 		}
-	} while (0); else if (_tmp23 == GTKAML_STATE_ID_SAX_PARSER_CONTAINER_STATE)
+	} while (0); else if (_tmp24 == GTKAML_STATE_ID_SAX_PARSER_CONTAINER_STATE)
 	do {
 		{
 			char* _tmp6;
@@ -275,7 +276,7 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 			} else {
 				GtkamlClassDefinition* _tmp9;
 				GtkamlClassDefinition* attribute_parent_class_definition;
-				GtkamlState* _tmp14;
+				GtkamlState* _tmp15;
 				/*no class with this name found, assume it's an attribute*/
 				_tmp9 = NULL;
 				attribute_parent_class_definition = (_tmp9 = gtkaml_state_get_class_definition (state), (_tmp9 == NULL ? NULL : g_object_ref (_tmp9)));
@@ -293,9 +294,16 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 					_tmp12 = NULL;
 					fqan = (_tmp13 = (_tmp12 = localname, (_tmp12 == NULL ? NULL : g_strdup (_tmp12))), (fqan = (g_free (fqan), NULL)), _tmp13);
 				}
-				_tmp14 = NULL;
-				gtkaml_state_stack_push (self->priv->_states, (_tmp14 = gtkaml_state_new (GTKAML_STATE_ID_SAX_PARSER_ATTRIBUTE_STATE, attribute_parent_class_definition, NULL, fqan)));
-				(_tmp14 == NULL ? NULL : (_tmp14 = (g_object_unref (_tmp14), NULL)));
+				if (gee_collection_get_size (GEE_COLLECTION (attrs)) > 0) {
+					char* _tmp14;
+					/*an attribute cannot have.. attributes*/
+					_tmp14 = NULL;
+					vala_report_error (source_reference, (_tmp14 = g_strdup_printf ("No class %s found.", fqan)));
+					_tmp14 = (g_free (_tmp14), NULL);
+				}
+				_tmp15 = NULL;
+				gtkaml_state_stack_push (self->priv->_states, (_tmp15 = gtkaml_state_new (GTKAML_STATE_ID_SAX_PARSER_ATTRIBUTE_STATE, attribute_parent_class_definition, NULL, fqan)));
+				(_tmp15 == NULL ? NULL : (_tmp15 = (g_object_unref (_tmp15), NULL)));
 				(attribute_parent_class_definition == NULL ? NULL : (attribute_parent_class_definition = (g_object_unref (attribute_parent_class_definition), NULL)));
 			}
 			if (vala_report_get_errors () > 0) {
@@ -311,48 +319,49 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 			fqan = (g_free (fqan), NULL);
 			break;
 		}
-	} while (0); else if (_tmp23 == GTKAML_STATE_ID_SAX_PARSER_ATTRIBUTE_STATE)
+	} while (0); else if (_tmp24 == GTKAML_STATE_ID_SAX_PARSER_ATTRIBUTE_STATE)
 	do {
 		{
-			char* _tmp16;
-			ValaClass* _tmp17;
+			char* _tmp17;
+			ValaClass* _tmp18;
 			ValaClass* clazz;
 			GtkamlClassDefinition* attribute_value_definition;
-			char* _tmp20;
-			GtkamlComplexAttribute* _tmp21;
+			char* _tmp21;
+			GtkamlComplexAttribute* _tmp22;
 			GtkamlComplexAttribute* attr;
-			GtkamlState* _tmp22;
+			GtkamlState* _tmp23;
 			/*a tag found within an attribute state switches us to container_state*/
 			if (gtkaml_state_get_attribute (state) != NULL) {
-				char* _tmp15;
+				char* _tmp16;
 				/*this was created by non-discardable text nodes*/
-				_tmp15 = NULL;
-				vala_report_error (source_reference, (_tmp15 = g_strdup_printf ("Incorrect attribute definition for %s", gtkaml_state_get_attribute_name (state))));
-				_tmp15 = (g_free (_tmp15), NULL);
+				_tmp16 = NULL;
+				vala_report_error (source_reference, (_tmp16 = g_strdup_printf ("Incorrect attribute definition for %s", gtkaml_state_get_attribute_name (state))));
+				_tmp16 = (g_free (_tmp16), NULL);
 				gtkaml_sax_parser_stop_parsing (self);
 				(attrs == NULL ? NULL : (attrs = (g_object_unref (attrs), NULL)));
 				(state == NULL ? NULL : (state = (g_object_unref (state), NULL)));
 				(source_reference == NULL ? NULL : (source_reference = (g_object_unref (source_reference), NULL)));
 				return;
 			}
-			_tmp16 = NULL;
 			_tmp17 = NULL;
-			clazz = (_tmp17 = gtkaml_sax_parser_lookup_class (self, (_tmp16 = gtkaml_sax_parser_prefix_to_namespace (self, prefix)), localname), (_tmp16 = (g_free (_tmp16), NULL)), _tmp17);
+			_tmp18 = NULL;
+			clazz = (_tmp18 = gtkaml_sax_parser_lookup_class (self, (_tmp17 = gtkaml_sax_parser_prefix_to_namespace (self, prefix)), localname), (_tmp17 = (g_free (_tmp17), NULL)), _tmp18);
 			attribute_value_definition = NULL;
 			if (clazz != NULL) {
-				GtkamlClassDefinition* _tmp18;
+				GtkamlClassDefinition* _tmp19;
 				/*this is a member/container child object*/
-				_tmp18 = NULL;
-				attribute_value_definition = (_tmp18 = gtkaml_sax_parser_get_child_for_container (self, clazz, NULL, attrs, prefix), (attribute_value_definition == NULL ? NULL : (attribute_value_definition = (g_object_unref (attribute_value_definition), NULL))), _tmp18);
-			} else {
-				char* _tmp19;
 				_tmp19 = NULL;
-				vala_report_error (source_reference, (_tmp19 = g_strdup_printf ("No class %s found", localname)));
-				_tmp19 = (g_free (_tmp19), NULL);
+				attribute_value_definition = (_tmp19 = gtkaml_sax_parser_get_child_for_container (self, clazz, NULL, attrs, prefix), (attribute_value_definition == NULL ? NULL : (attribute_value_definition = (g_object_unref (attribute_value_definition), NULL))), _tmp19);
+			} else {
+				char* _tmp20;
+				_tmp20 = NULL;
+				vala_report_error (source_reference, (_tmp20 = g_strdup_printf ("No class %s found", localname)));
+				_tmp20 = (g_free (_tmp20), NULL);
 			}
-			_tmp20 = NULL;
 			_tmp21 = NULL;
-			attr = (_tmp21 = gtkaml_complex_attribute_new ((_tmp20 = gtkaml_sax_parser_strip_attribute_hyphens (self, gtkaml_state_get_attribute_name (state))), attribute_value_definition), (_tmp20 = (g_free (_tmp20), NULL)), _tmp21);
+			_tmp22 = NULL;
+			attr = (_tmp22 = gtkaml_complex_attribute_new ((_tmp21 = gtkaml_sax_parser_strip_attribute_hyphens (self, gtkaml_state_get_attribute_name (state))), attribute_value_definition), (_tmp21 = (g_free (_tmp21), NULL)), _tmp22);
+			gtkaml_state_set_attribute (state, GTKAML_ATTRIBUTE (attr));
 			/*add the attribute into the parent container*/
 			gtkaml_class_definition_add_attribute (gtkaml_state_get_class_definition (state), GTKAML_ATTRIBUTE (attr));
 			if (vala_report_get_errors () > 0) {
@@ -365,9 +374,9 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 				(source_reference == NULL ? NULL : (source_reference = (g_object_unref (source_reference), NULL)));
 				return;
 			}
-			_tmp22 = NULL;
-			gtkaml_state_stack_push (self->priv->_states, (_tmp22 = gtkaml_state_new (GTKAML_STATE_ID_SAX_PARSER_CONTAINER_STATE, attribute_value_definition, NULL, NULL)));
-			(_tmp22 == NULL ? NULL : (_tmp22 = (g_object_unref (_tmp22), NULL)));
+			_tmp23 = NULL;
+			gtkaml_state_stack_push (self->priv->_states, (_tmp23 = gtkaml_state_new (GTKAML_STATE_ID_SAX_PARSER_CONTAINER_STATE, attribute_value_definition, NULL, NULL)));
+			(_tmp23 == NULL ? NULL : (_tmp23 = (g_object_unref (_tmp23), NULL)));
 			(clazz == NULL ? NULL : (clazz = (g_object_unref (clazz), NULL)));
 			(attribute_value_definition == NULL ? NULL : (attribute_value_definition = (g_object_unref (attribute_value_definition), NULL)));
 			(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
@@ -410,13 +419,28 @@ void gtkaml_sax_parser_characters (GtkamlSAXParser* self, const char* data, gint
 
 
 void gtkaml_sax_parser_end_element (GtkamlSAXParser* self, const char* localname, const char* prefix, const char* URI) {
-	GtkamlState* _tmp0;
+	GtkamlState* last_state;
+	char* _tmp1;
+	char* _tmp0;
+	gboolean _tmp2;
 	g_return_if_fail (GTKAML_IS_SAX_PARSER (self));
 	g_return_if_fail (localname != NULL);
 	g_return_if_fail (URI != NULL);
+	last_state = gtkaml_state_stack_pop (self->priv->_states);
+	/*check if we were in 'attribute' state but no sub-tags or no text/cdata blocks were encountered*/
+	_tmp1 = NULL;
 	_tmp0 = NULL;
-	_tmp0 = gtkaml_state_stack_pop (self->priv->_states);
-	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
+	if ((_tmp2 = (last_state != NULL) && (gtkaml_state_get_state_id (last_state) == GTKAML_STATE_ID_SAX_PARSER_ATTRIBUTE_STATE) && (gtkaml_state_get_attribute (last_state) == NULL) && (_vala_strcmp0 (gtkaml_state_get_attribute_name (last_state), (_tmp0 = g_strconcat (self->gtkaml_prefix, ".preconstruct", NULL))) != 0) && (_vala_strcmp0 (gtkaml_state_get_attribute_name (last_state), (_tmp1 = g_strconcat (self->gtkaml_prefix, ".construct", NULL))) != 0), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2)) {
+		char* _tmp4;
+		ValaSourceReference* _tmp3;
+		_tmp4 = NULL;
+		_tmp3 = NULL;
+		vala_report_error ((_tmp3 = gtkaml_sax_parser_create_source_reference (self)), (_tmp4 = g_strdup_printf ("%s is not well defined or is not an attribute of %s", gtkaml_state_get_attribute_name (last_state), gtkaml_class_definition_get_base_full_name (gtkaml_state_get_class_definition (last_state)))));
+		_tmp4 = (g_free (_tmp4), NULL);
+		(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
+		gtkaml_sax_parser_stop_parsing (self);
+	}
+	(last_state == NULL ? NULL : (last_state = (g_object_unref (last_state), NULL)));
 }
 
 
@@ -1112,6 +1136,7 @@ static void gtkaml_sax_parser_set_context (GtkamlSAXParser* self, ValaCodeContex
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_context = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_context == NULL ? NULL : (self->priv->_context = (g_object_unref (self->priv->_context), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "context");
 }
 
 
@@ -1124,6 +1149,7 @@ ValaSourceFile* gtkaml_sax_parser_get_source_file (GtkamlSAXParser* self) {
 static void gtkaml_sax_parser_set_source_file (GtkamlSAXParser* self, ValaSourceFile* value) {
 	g_return_if_fail (GTKAML_IS_SAX_PARSER (self));
 	self->priv->_source_file = value;
+	g_object_notify (((GObject *) (self)), "source-file");
 }
 
 
@@ -1239,7 +1265,7 @@ static void gtkaml_sax_parser_class_init (GtkamlSAXParserClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = gtkaml_sax_parser_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gtkaml_sax_parser_set_property;
 	G_OBJECT_CLASS (klass)->constructor = gtkaml_sax_parser_constructor;
-	G_OBJECT_CLASS (klass)->dispose = gtkaml_sax_parser_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gtkaml_sax_parser_finalize;
 	GTKAML_SAX_PARSER_CLASS (klass)->parse = gtkaml_sax_parser_real_parse;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_SAX_PARSER_CONTEXT, g_param_spec_object ("context", "context", "context", VALA_TYPE_CODE_CONTEXT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_SAX_PARSER_SOURCE_FILE, g_param_spec_object ("source-file", "source-file", "source-file", VALA_TYPE_SOURCE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
@@ -1254,7 +1280,7 @@ static void gtkaml_sax_parser_instance_init (GtkamlSAXParser * self) {
 }
 
 
-static void gtkaml_sax_parser_dispose (GObject * obj) {
+static void gtkaml_sax_parser_finalize (GObject * obj) {
 	GtkamlSAXParser * self;
 	self = GTKAML_SAX_PARSER (obj);
 	(self->priv->_context == NULL ? NULL : (self->priv->_context = (g_object_unref (self->priv->_context), NULL)));
@@ -1264,13 +1290,13 @@ static void gtkaml_sax_parser_dispose (GObject * obj) {
 	(self->priv->_prefixes_namespaces == NULL ? NULL : (self->priv->_prefixes_namespaces = (g_object_unref (self->priv->_prefixes_namespaces), NULL)));
 	(self->priv->_root_class_definition == NULL ? NULL : (self->priv->_root_class_definition = (g_object_unref (self->priv->_root_class_definition), NULL)));
 	self->gtkaml_prefix = (g_free (self->gtkaml_prefix), NULL);
-	G_OBJECT_CLASS (gtkaml_sax_parser_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gtkaml_sax_parser_parent_class)->finalize (obj);
 }
 
 
 GType gtkaml_sax_parser_get_type (void) {
 	static GType gtkaml_sax_parser_type_id = 0;
-	if (G_UNLIKELY (gtkaml_sax_parser_type_id == 0)) {
+	if (gtkaml_sax_parser_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlSAXParserClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_sax_parser_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlSAXParser), 0, (GInstanceInitFunc) gtkaml_sax_parser_instance_init };
 		gtkaml_sax_parser_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlSAXParser", &g_define_type_info, 0);
 	}
