@@ -35,7 +35,7 @@ enum  {
 	GTKAML_SIMPLE_ATTRIBUTE_VALUE
 };
 static gpointer gtkaml_simple_attribute_parent_class = NULL;
-static void gtkaml_simple_attribute_dispose (GObject * obj);
+static void gtkaml_simple_attribute_finalize (GObject * obj);
 
 
 
@@ -63,6 +63,7 @@ void gtkaml_simple_attribute_set_value (GtkamlSimpleAttribute* self, const char*
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_value = (g_free (self->priv->_value), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "value");
 }
 
 
@@ -99,7 +100,7 @@ static void gtkaml_simple_attribute_class_init (GtkamlSimpleAttributeClass * kla
 	g_type_class_add_private (klass, sizeof (GtkamlSimpleAttributePrivate));
 	G_OBJECT_CLASS (klass)->get_property = gtkaml_simple_attribute_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gtkaml_simple_attribute_set_property;
-	G_OBJECT_CLASS (klass)->dispose = gtkaml_simple_attribute_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gtkaml_simple_attribute_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_SIMPLE_ATTRIBUTE_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
@@ -109,17 +110,17 @@ static void gtkaml_simple_attribute_instance_init (GtkamlSimpleAttribute * self)
 }
 
 
-static void gtkaml_simple_attribute_dispose (GObject * obj) {
+static void gtkaml_simple_attribute_finalize (GObject * obj) {
 	GtkamlSimpleAttribute * self;
 	self = GTKAML_SIMPLE_ATTRIBUTE (obj);
 	self->priv->_value = (g_free (self->priv->_value), NULL);
-	G_OBJECT_CLASS (gtkaml_simple_attribute_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gtkaml_simple_attribute_parent_class)->finalize (obj);
 }
 
 
 GType gtkaml_simple_attribute_get_type (void) {
 	static GType gtkaml_simple_attribute_type_id = 0;
-	if (G_UNLIKELY (gtkaml_simple_attribute_type_id == 0)) {
+	if (gtkaml_simple_attribute_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlSimpleAttributeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_simple_attribute_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlSimpleAttribute), 0, (GInstanceInitFunc) gtkaml_simple_attribute_instance_init };
 		gtkaml_simple_attribute_type_id = g_type_register_static (GTKAML_TYPE_ATTRIBUTE, "GtkamlSimpleAttribute", &g_define_type_info, 0);
 	}
