@@ -41,7 +41,7 @@ enum  {
 	GTKAML_STATE_ATTRIBUTE_NAME
 };
 static gpointer gtkaml_state_parent_class = NULL;
-static void gtkaml_state_dispose (GObject * obj);
+static void gtkaml_state_finalize (GObject * obj);
 
 
 
@@ -78,6 +78,7 @@ GtkamlStateId gtkaml_state_get_state_id (GtkamlState* self) {
 void gtkaml_state_set_state_id (GtkamlState* self, GtkamlStateId value) {
 	g_return_if_fail (GTKAML_IS_STATE (self));
 	self->priv->_state_id = value;
+	g_object_notify (((GObject *) (self)), "state-id");
 }
 
 
@@ -94,6 +95,7 @@ void gtkaml_state_set_class_definition (GtkamlState* self, GtkamlClassDefinition
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_class_definition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_class_definition == NULL ? NULL : (self->priv->_class_definition = (g_object_unref (self->priv->_class_definition), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "class-definition");
 }
 
 
@@ -110,6 +112,7 @@ void gtkaml_state_set_attribute (GtkamlState* self, GtkamlAttribute* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_attribute = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_attribute == NULL ? NULL : (self->priv->_attribute = (g_object_unref (self->priv->_attribute), NULL))), _tmp2);
+	g_object_notify (((GObject *) (self)), "attribute");
 }
 
 
@@ -126,6 +129,7 @@ void gtkaml_state_set_attribute_name (GtkamlState* self, const char* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_attribute_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_attribute_name = (g_free (self->priv->_attribute_name), NULL)), _tmp2);
+	g_object_notify (((GObject *) (self)), "attribute-name");
 }
 
 
@@ -180,7 +184,7 @@ static void gtkaml_state_class_init (GtkamlStateClass * klass) {
 	g_type_class_add_private (klass, sizeof (GtkamlStatePrivate));
 	G_OBJECT_CLASS (klass)->get_property = gtkaml_state_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gtkaml_state_set_property;
-	G_OBJECT_CLASS (klass)->dispose = gtkaml_state_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gtkaml_state_finalize;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_STATE_STATE_ID, g_param_spec_enum ("state-id", "state-id", "state-id", GTKAML_TYPE_STATE_ID, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_STATE_CLASS_DEFINITION, g_param_spec_object ("class-definition", "class-definition", "class-definition", GTKAML_TYPE_CLASS_DEFINITION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GTKAML_STATE_ATTRIBUTE, g_param_spec_object ("attribute", "attribute", "attribute", GTKAML_TYPE_ATTRIBUTE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -193,19 +197,19 @@ static void gtkaml_state_instance_init (GtkamlState * self) {
 }
 
 
-static void gtkaml_state_dispose (GObject * obj) {
+static void gtkaml_state_finalize (GObject * obj) {
 	GtkamlState * self;
 	self = GTKAML_STATE (obj);
 	(self->priv->_class_definition == NULL ? NULL : (self->priv->_class_definition = (g_object_unref (self->priv->_class_definition), NULL)));
 	(self->priv->_attribute == NULL ? NULL : (self->priv->_attribute = (g_object_unref (self->priv->_attribute), NULL)));
 	self->priv->_attribute_name = (g_free (self->priv->_attribute_name), NULL);
-	G_OBJECT_CLASS (gtkaml_state_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gtkaml_state_parent_class)->finalize (obj);
 }
 
 
 GType gtkaml_state_get_type (void) {
 	static GType gtkaml_state_type_id = 0;
-	if (G_UNLIKELY (gtkaml_state_type_id == 0)) {
+	if (gtkaml_state_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlStateClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_state_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlState), 0, (GInstanceInitFunc) gtkaml_state_instance_init };
 		gtkaml_state_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlState", &g_define_type_info, 0);
 	}
