@@ -38,22 +38,12 @@ enum  {
 };
 static GeeArrayList* gtkaml_state_stack_get_array_list (GtkamlStateStack* self);
 static void gtkaml_state_stack_set_array_list (GtkamlStateStack* self, GeeArrayList* value);
+static GObject * gtkaml_state_stack_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer gtkaml_state_stack_parent_class = NULL;
-static void gtkaml_state_stack_dispose (GObject * obj);
+static void gtkaml_state_stack_finalize (GObject * obj);
 
 
 
-GtkamlStateStack* gtkaml_state_stack_new (void) {
-	GtkamlStateStack * self;
-	GeeArrayList* _tmp0;
-	self = g_object_newv (GTKAML_TYPE_STATE_STACK, 0, NULL);
-	_tmp0 = NULL;
-	gtkaml_state_stack_set_array_list (self, (_tmp0 = gee_array_list_new (GTKAML_TYPE_STATE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)));
-	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
-	return self;
-}
-
-
 void gtkaml_state_stack_push (GtkamlStateStack* self, GtkamlState* element) {
 	g_return_if_fail (GTKAML_IS_STATE_STACK (self));
 	g_return_if_fail (GTKAML_IS_STATE (element));
@@ -94,6 +84,16 @@ GtkamlState* gtkaml_state_stack_pop (GtkamlStateStack* self) {
 }
 
 
+/** 
+ * Simple, specialized, stack implementation using a Gee.List
+ */
+GtkamlStateStack* gtkaml_state_stack_new (void) {
+	GtkamlStateStack * self;
+	self = g_object_newv (GTKAML_TYPE_STATE_STACK, 0, NULL);
+	return self;
+}
+
+
 static GeeArrayList* gtkaml_state_stack_get_array_list (GtkamlStateStack* self) {
 	g_return_val_if_fail (GTKAML_IS_STATE_STACK (self), NULL);
 	return self->priv->_array_list;
@@ -110,6 +110,25 @@ static void gtkaml_state_stack_set_array_list (GtkamlStateStack* self, GeeArrayL
 }
 
 
+static GObject * gtkaml_state_stack_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
+	GObject * obj;
+	GtkamlStateStackClass * klass;
+	GObjectClass * parent_class;
+	GtkamlStateStack * self;
+	klass = GTKAML_STATE_STACK_CLASS (g_type_class_peek (GTKAML_TYPE_STATE_STACK));
+	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
+	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
+	self = GTKAML_STATE_STACK (obj);
+	{
+		GeeArrayList* _tmp0;
+		_tmp0 = NULL;
+		gtkaml_state_stack_set_array_list (self, (_tmp0 = gee_array_list_new (GTKAML_TYPE_STATE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)));
+		(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
+	}
+	return obj;
+}
+
+
 static void gtkaml_state_stack_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GtkamlStateStack * self;
 	self = GTKAML_STATE_STACK (object);
@@ -137,7 +156,8 @@ static void gtkaml_state_stack_class_init (GtkamlStateStackClass * klass) {
 	g_type_class_add_private (klass, sizeof (GtkamlStateStackPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gtkaml_state_stack_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gtkaml_state_stack_set_property;
-	G_OBJECT_CLASS (klass)->dispose = gtkaml_state_stack_dispose;
+	G_OBJECT_CLASS (klass)->constructor = gtkaml_state_stack_constructor;
+	G_OBJECT_CLASS (klass)->finalize = gtkaml_state_stack_finalize;
 }
 
 
@@ -146,17 +166,17 @@ static void gtkaml_state_stack_instance_init (GtkamlStateStack * self) {
 }
 
 
-static void gtkaml_state_stack_dispose (GObject * obj) {
+static void gtkaml_state_stack_finalize (GObject * obj) {
 	GtkamlStateStack * self;
 	self = GTKAML_STATE_STACK (obj);
 	(self->priv->_array_list == NULL ? NULL : (self->priv->_array_list = (g_object_unref (self->priv->_array_list), NULL)));
-	G_OBJECT_CLASS (gtkaml_state_stack_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gtkaml_state_stack_parent_class)->finalize (obj);
 }
 
 
 GType gtkaml_state_stack_get_type (void) {
 	static GType gtkaml_state_stack_type_id = 0;
-	if (G_UNLIKELY (gtkaml_state_stack_type_id == 0)) {
+	if (gtkaml_state_stack_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlStateStackClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_state_stack_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlStateStack), 0, (GInstanceInitFunc) gtkaml_state_stack_instance_init };
 		gtkaml_state_stack_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlStateStack", &g_define_type_info, 0);
 	}
