@@ -29,7 +29,7 @@ enum  {
 	GTKAML_XML_ATTRIBUTE_DUMMY_PROPERTY
 };
 static gpointer gtkaml_xml_attribute_parent_class = NULL;
-static void gtkaml_xml_attribute_dispose (GObject * obj);
+static void gtkaml_xml_attribute_finalize (GObject * obj);
 
 
 
@@ -45,7 +45,7 @@ GtkamlXmlAttribute* gtkaml_xml_attribute_new (void) {
 
 static void gtkaml_xml_attribute_class_init (GtkamlXmlAttributeClass * klass) {
 	gtkaml_xml_attribute_parent_class = g_type_class_peek_parent (klass);
-	G_OBJECT_CLASS (klass)->dispose = gtkaml_xml_attribute_dispose;
+	G_OBJECT_CLASS (klass)->finalize = gtkaml_xml_attribute_finalize;
 }
 
 
@@ -53,20 +53,20 @@ static void gtkaml_xml_attribute_instance_init (GtkamlXmlAttribute * self) {
 }
 
 
-static void gtkaml_xml_attribute_dispose (GObject * obj) {
+static void gtkaml_xml_attribute_finalize (GObject * obj) {
 	GtkamlXmlAttribute * self;
 	self = GTKAML_XML_ATTRIBUTE (obj);
 	self->localname = (g_free (self->localname), NULL);
 	self->prefix = (g_free (self->prefix), NULL);
 	self->URI = (g_free (self->URI), NULL);
 	self->value = (g_free (self->value), NULL);
-	G_OBJECT_CLASS (gtkaml_xml_attribute_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (gtkaml_xml_attribute_parent_class)->finalize (obj);
 }
 
 
 GType gtkaml_xml_attribute_get_type (void) {
 	static GType gtkaml_xml_attribute_type_id = 0;
-	if (G_UNLIKELY (gtkaml_xml_attribute_type_id == 0)) {
+	if (gtkaml_xml_attribute_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlXmlAttributeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_xml_attribute_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlXmlAttribute), 0, (GInstanceInitFunc) gtkaml_xml_attribute_instance_init };
 		gtkaml_xml_attribute_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlXmlAttribute", &g_define_type_info, 0);
 	}
