@@ -29,7 +29,7 @@ enum  {
 	XML_NAMESPACE_DUMMY_PROPERTY
 };
 static gpointer xml_namespace_parent_class = NULL;
-static void xml_namespace_dispose (GObject * obj);
+static void xml_namespace_finalize (GObject * obj);
 
 
 
@@ -45,7 +45,7 @@ XmlNamespace* xml_namespace_new (void) {
 
 static void xml_namespace_class_init (XmlNamespaceClass * klass) {
 	xml_namespace_parent_class = g_type_class_peek_parent (klass);
-	G_OBJECT_CLASS (klass)->dispose = xml_namespace_dispose;
+	G_OBJECT_CLASS (klass)->finalize = xml_namespace_finalize;
 }
 
 
@@ -53,18 +53,18 @@ static void xml_namespace_instance_init (XmlNamespace * self) {
 }
 
 
-static void xml_namespace_dispose (GObject * obj) {
+static void xml_namespace_finalize (GObject * obj) {
 	XmlNamespace * self;
 	self = XML_NAMESPACE (obj);
 	self->prefix = (g_free (self->prefix), NULL);
 	self->URI = (g_free (self->URI), NULL);
-	G_OBJECT_CLASS (xml_namespace_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (xml_namespace_parent_class)->finalize (obj);
 }
 
 
 GType xml_namespace_get_type (void) {
 	static GType xml_namespace_type_id = 0;
-	if (G_UNLIKELY (xml_namespace_type_id == 0)) {
+	if (xml_namespace_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (XmlNamespaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) xml_namespace_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (XmlNamespace), 0, (GInstanceInitFunc) xml_namespace_instance_init };
 		xml_namespace_type_id = g_type_register_static (G_TYPE_OBJECT, "XmlNamespace", &g_define_type_info, 0);
 	}
